<?php
/**
 * Core Design FAQ plugin for Joomla! 1.6
 * @author		Daniel Rataj, <info@greatjoomla.com>
 * @package		Joomla
 * @subpackage	Content
 * @category   	Plugin
 * @version		2.0.0
 * @copyright	Copyright (C) 2007 - 2011 Great Joomla!, http://www.greatjoomla.com
 * @license		http://www.gnu.org/copyleft/gpl.html GNU/GPL 3
 * 
 * This file is part of Great Joomla! extension.   
 * This extension is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This extension is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

/**
 * Joomla!
 * 
 * @version 1.6.0
 */
class cdfaq_com_content {
	
	private	$catid 			= 	array();
	private	$overrides 		= 	'';
	private $plg_params		=	null;
	
	/**
	 * Constructor
	 * 
	 * @param 	array			$catid
	 * @param 	object			$plg_params
	 * @param 	string			$overrides
	 */
	public function __construct($catid = array(), $plg_params = null, $overrides = '') {
		$this->catid 		= $catid;
		$this->plg_params 	= $plg_params;
		$this->overrides	= $overrides;
	}
	
	/**
	 * Get Instance
	 * 
	 * @param	array		$catid
	 * @param	object		$plg_params
	 * @param 	string		$overrides
	 * @return 	instance
	 */
	public function getInstance($catid = array(), $plg_params = null, $overrides = '') {
		static $instance;
		if ($instance == null) {
			$instance = new cdfaq_com_content($catid, $plg_params);
		}
		
		return $instance;
	}
	
	public function getArticles() {
		$articles = array();
		$articles_instance = array();
		
		if ($categories = $this->getCategories()) {
			
			$app = JFactory::getApplication();
			$user		= JFactory::getUser();
			
			JModel::addIncludePath(dirname(dirname(__FILE__)) . DS . 'models');
			
			require_once JPATH_SITE . DS . 'components' . DS . 'com_content' . DS . 'helpers' . DS . 'query.php';
			
			$model = JModel::getInstance('Articles', 'plgContentCdFaqContentModel', array('ignore_request' => true));
			
			foreach($categories as $category) {
				
				if (!$category) continue; // prevent non-existing category
		
				$params = $app->getParams();
				$model->setState('params', $params);
		
				if ((!$user->authorise('core.edit.state', 'com_content')) &&  (!$user->authorise('core.edit', 'com_content'))){
					// filter on published for those who do not have edit or edit.state rights.
					$model->setState('filter.published', 1);
				}
		
				$model->setState('filter.language', $app->getLanguageFilter());
		
				// process show_noauth parameter
				if (!$params->get('show_noauth')) {
					$model->setState('filter.access', true);
				}
				else {
					$model->setState('filter.access', false);
				}
		
				$model->setState('filter.category_id', $category->id);
				$model->setState('list.ordering', ContentHelperQuery::orderbySecondary($this->plg_params->get('orderby_sec', '')));
				$model->setState('list.direction', ''); // must be empty to get list.ordering value in correct format
				
				$articles = $model->getItems();
				
				$category->articles = $articles;
				
				$articles_instance[] = $category;
			}
		}
		
		return $articles_instance;
	}
	
	/**
	 * Get categories
	 * 
	 * @return array
	 */
	public function getCategories() {
		$categories = array();
		foreach($this->catid as $catid) {
			$model = JModel::getInstance('Category', 'ContentModel', array('ignore_request' => true));
			
			$model->setState('category.id', $catid);
			
			$category = $model->getCategory();
			
			$temp_object = new stdClass();
			$temp_object->id = $category->id;
			$temp_object->title = $category->title;
			$temp_object->alias = $category->alias;
			$temp_object->description = $category->description;
			
			$categories[] = $temp_object;
		}
	
		return $categories;
	}	
}
?>