/**
 * Core Design FAQ plugin for Joomla! 1.6
 * @author		Daniel Rataj, <info@greatjoomla.com>
 * @package		Joomla
 * @subpackage	Content
 * @category   	Plugin
 * @version		2.0.0
 * @copyright	Copyright (C) 2007 - 2011 Great Joomla!, http://www.greatjoomla.com
 * @license		http://www.gnu.org/copyleft/gpl.html GNU/GPL 3
 * 
 * This file is part of Great Joomla! extension.   
 * This extension is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This extension is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

(function($) {
	
	$.cdfaq = {
			
		/**
		 * Init application
		 * 
		 * @return void
		 */
		initiator: function() {		
			var $PHP_JS = new PHP_JS(),
			container = $('div.cdfaq'),
			navigation = $('div.cdfaq_navigation');
		
			// no faq container
			if (container.length === 0) return false;
			
			// show more toggle
			$.cdfaq.toggleShowMoreRoutine();
			
			// filter
			$.cdfaq.filter();
			
			// go to top element
			$.cdfaq.themeElement(container.find('div.cdfaq_list').find('div.goToTop'));
			
			// scrolling
			if ($.cdfaq.settings.scrollSpeed) {
				
				// navigation
				navigation.find('a').click(function(e) {
					e.preventDefault();
					
					// change hash in URL
					var link = $(this);
					var change_hash = function() {
						window.location.hash = link.attr('href');
					};
					
					$.cdfaq.scrollToElement(container.find('a[name="' + $PHP_JS.substr($(this).attr('href'), 1) + '"]'), $.cdfaq.settings.scrollSpeed, change_hash);
					
				});
				
				// go to top element
				container.find('div.cdfaq_list').find('div.goToTop').children('a').click(function(e) {
					e.preventDefault();
					
					// change hash in URL
					var link = $(this);
					var change_hash = function() {
						window.location.hash = link.attr('href');
					};
					
					$.cdfaq.scrollToElement(navigation, $.cdfaq.settings.scrollSpeed, change_hash);
				});
					
			}
		},
		
		/**
		 * Toggle "Show more" routine
		 * 
		 * @return void
		 */
		toggleShowMoreRoutine: function() {
			
			if ($('div.show_less_more').length === 0) return false;
			
			$('div.show_less_more a').click(function(e) {
				e.preventDefault();
				var link = $(this);
				
				var fulltext_container = $(this).parent('div').find('div.fulltext');
				fulltext_container.toggle(0, 
						function() {
							if (fulltext_container.is(':visible')) {
								link.attr('title', $.cdfaq.language.CDFAQ_LESS_INFO).text($.cdfaq.language.CDFAQ_LESS_INFO);
							} else {
								link.attr('title', $.cdfaq.language.CDFAQ_MORE_INFO).text($.cdfaq.language.CDFAQ_MORE_INFO);
							}
						}
					);
			});
		},
		
		/**
		 * Filter
		 * 
		 * @return void
		 */
		filter: function() {
			
			var $PHP_JS = new PHP_JS(),
			filter = $('div.cdfaq_filter input[name="filter"]');
			
			if (filter.length === 0) return false;
			
			filter.keyup(function(e) {
				e.preventDefault();
				
				var accordion_instance = $('div.ui-accordion');
				
				var val = ($(this).val() + '').toLowerCase();
				
				accordion_instance.find('h3.ui-accordion-header a').each(function(n, el) {
					
					var accordion_header = $(el).closest('h3.ui-accordion-header');
					
					var headertext = ($(el).text() + '').toLowerCase();
					
					if ($PHP_JS.strpos(headertext, val) === false) {
						accordion_header.hide($.cdfaq.settings.filterSlideSpeed);
						accordion_header.closest('div.ui-accordion').children('div.cdfaq_list').children('h3').each(function(n, el) {
							if ($(el).is(':animated') && $(el).hasClass('ui-state-active')) {
								$(el).closest('div.ui-accordion').accordion('activate', n);
								filter.focus();
							}
						});
							
					} else {
						accordion_header.show($.cdfaq.settings.filterSlideSpeed);
					}
					
				});
				
			});
			
		},
		
		/**
		 * Scroll element
		 * 
		 * @param element
		 * @param speed
		 * @return boolean
		 */
		scrollToElement: function(element, speed, func) {
			
	        if (speed === 0) return false;
	        if (element.length === 0) return false;
	        
	        if (typeof(func) !== 'function') func = function() {};
	        
	        ($.browser.safari) ? $('body') : $('html').animate({
	            scrollTop: element.offset().top,
	            scrollLeft: element.offset().left
	        }, speed, func);
	        
	        return true;
	        
	    },
	    
	    /**
	     * Theme elements
	     * 
	     * @param elements
	     * @return void
	     */
	    themeElement: function(elements) {
	    	elements.each(function() {
				$(this)
					.hover(
						function() {
							$(this).addClass('ui-state-hover');
						},
						function() {
							$(this).removeClass('ui-state-hover');
						}
					);
			});
	    }
	};
})(jQuery);